aboutsummaryrefslogtreecommitdiffstats
path: root/Software/Visual_Studio/MachineStudio/Tango.MachineStudio.Common/MachineStudioSettings.cs
diff options
context:
space:
mode:
Diffstat (limited to 'Software/Visual_Studio/MachineStudio/Tango.MachineStudio.Common/MachineStudioSettings.cs')
-rw-r--r--Software/Visual_Studio/MachineStudio/Tango.MachineStudio.Common/MachineStudioSettings.cs7
1 files changed, 6 insertions, 1 deletions
diff --git a/Software/Visual_Studio/MachineStudio/Tango.MachineStudio.Common/MachineStudioSettings.cs b/Software/Visual_Studio/MachineStudio/Tango.MachineStudio.Common/MachineStudioSettings.cs
index 22ed1a33d..06d5d44c5 100644
--- a/Software/Visual_Studio/MachineStudio/Tango.MachineStudio.Common/MachineStudioSettings.cs
+++ b/Software/Visual_Studio/MachineStudio/Tango.MachineStudio.Common/MachineStudioSettings.cs
@@ -74,11 +74,16 @@ namespace Tango.MachineStudio.Common
public bool UseExternalBridgeEmulator { get; set; }
/// <summary>
/// Gets or sets the studio modules bounds.
/// </summary>
public List<StudioModuleBounds> StudioModulesBounds { get; set; }
/// <summary>
+ /// Gets or sets the last module that was opened in the main window.
+ /// </summary>
+ public String LastMainModuleName { get; set; }
+
+ /// <summary>
/// Initializes a new instance of the <see cref="MachineStudio"/> class.
/// </summary>
public MachineStudioSettings()
@@ -74,11 +74,16 @@ namespace Tango.MachineStudio.Common
public bool UseExternalBridgeEmulator { get; set; }
/// <summary>
- /// Gets or sets the studio modules bounds.
+ /// Gets or sets the last bounds of modules open windows.
/// </summary>
public List<StudioModuleBounds> StudioModulesBounds { get; set; }